@@ -11,7 +11,7 @@
 #  implied warranty of MERCHANTABILITY or FITNESS FOR A PARTICULAR
 #  PURPOSE.  See the GNU General Public License for more details.
 #
-# $Id: common.py,v 1.22 2004/09/27 16:09:22 atzm Exp $
+# $Id: common.py,v 1.25 2004/10/31 13:28:17 atzm Exp $
 #
 
 import os, sys
@@ -19,7 +19,7 @@ import gtk
 
 # common defines
 APP = 'GBottler'
-VER = '0.1.2'
+VER = '0.1.3.1'
 
 VOTE  = "Vote"
 AGREE = "Agree"
@@ -177,7 +177,7 @@ def open_error_dialog(label, parent=None, stock=gtk.STOCK_DIALOG_ERROR):
 	d = None
 	return
 
-def open_simple_entry_dialog(title, label, parent=None, stock=gtk.STOCK_DIALOG_QUESTION):
+def open_simple_entry_dialog(title, label, default="", parent=None, stock=gtk.STOCK_DIALOG_QUESTION):
 	d = gtk.Dialog(title, parent,
 				   gtk.DIALOG_DESTROY_WITH_PARENT|gtk.DIALOG_MODAL|gtk.DIALOG_NO_SEPARATOR,
 				   (gtk.STOCK_CANCEL, gtk.RESPONSE_CANCEL, gtk.STOCK_OK, gtk.RESPONSE_OK))
@@ -185,6 +185,8 @@ def open_simple_entry_dialog(title, label, parent=None, stock=gtk.STOCK_DIALOG_Q
 	h = get_icon_box(stock, label, gtk.ICON_SIZE_DIALOG)
 	d.vbox.pack_start(h)
 	e = gtk.Entry()
+	e.set_text(default)
+	e.connect("activate", lambda x: d.emit("response", gtk.RESPONSE_OK))
 	e.show()
 	d.vbox.pack_start(e)
 	d.show()
