@@ -11,7 +11,7 @@
 #  implied warranty of MERCHANTABILITY or FITNESS FOR A PARTICULAR
 #  PURPOSE.  See the GNU General Public License for more details.
 #
-# $Id: logwindow.py,v 1.20 2004/09/27 22:39:07 atzm Exp $
+# $Id: logwindow.py,v 1.24 2004/10/11 14:46:27 atzm Exp $
 #
 
 import gtk
@@ -22,15 +22,20 @@ from textmanager    import TextManager
 from logbook        import LogBook
 from loglist        import LogList
 from logmanager     import XMLLogWriter, XMLLogOpener, LogFetchOperator
+from prefs          import PreferenceManager
 
 from common import *
 
 class LogWindow:
-	def __init__(self, app):
+	def __init__(self, app, prefs):
 # === Definition of Basic Const === #
 		self.app    = app
 		accel_group = gtk.AccelGroup()
 
+		self.logtabpos  = int(prefs.get(PreferenceManager.PREF_POSITION_TAB))
+		self.logpagepos = prefs.get(PreferenceManager.PREF_POSITION_PAGE)
+		self.logtabfocus= prefs.get(PreferenceManager.PREF_FOCUS_TAB)
+
 		self.set_self_msg()
 		self.volley_canceler = False
 
@@ -119,11 +124,15 @@ class LogWindow:
 # === Create Popup Menu for LogList === #
 		p_menu = (
 			( "/%s" % unicode(_("Play")), "<control>p", self.play, 0, "<StockItem>", gtk.STOCK_REFRESH ),
-			( "/%s" % unicode(_("Volley")), None, self.volley, 0, None ),
+			( "/%s" % unicode(_("Volley")), None, self.volley, 0, "<StockItem>", gtk.STOCK_GOTO_TOP ),
 			( '/sep1', None, None, 0, "<Separator>" ),
-			( "/%s" % unicode(_("Cancel to play")), None, self.cancel_play, 0, "<StockItem>", gtk.STOCK_CANCEL ),
-			( "/%s" % unicode(_("Cancel to play all at this page")), None, self.cancel_play_page, 0, "<StockItem>", gtk.STOCK_CANCEL ),
-			( "/%s" % unicode(_("Cancel to play all")), None, self.cancel_play_all, 0, "<StockItem>", gtk.STOCK_CANCEL ),
+			( "/%s" % unicode(_("Cancel to play")), None, None, 0, "<Branch>" ),
+			( "/%s/%s" % (unicode(_("Cancel to play")), unicode(_("This bottle"))),
+			  None, self.cancel_play, 0, "<StockItem>", gtk.STOCK_CANCEL ),
+			( "/%s/%s" % (unicode(_("Cancel to play")), unicode(_("This page"))),
+			  None, self.cancel_play_page, 0, "<StockItem>", gtk.STOCK_CANCEL ),
+			( "/%s/%s" % (unicode(_("Cancel to play")), unicode(_("All"))),
+			  None, self.cancel_play_all, 0, "<StockItem>", gtk.STOCK_CANCEL ),
 			( '/sep2', None, None, 0, "<Separator>" ),
 			( "/%s" % unicode(_("Vote")), "<control><alt>v", self.voting, 0, "<StockItem>", gtk.STOCK_YES ),
 			( "/%s" % unicode(_("Agree")), "<control><alt>a", self.agreeing, 0, "<StockItem>", gtk.STOCK_NO ),
@@ -143,7 +152,7 @@ class LogWindow:
 		self.ai = self.p_ifact.get_item("/%s" % unicode(_("Agree"), "utf-8"))
 
 # === Create Log Viewer === #
-		self.textmanager = TextManager(self, self.app.prefs)
+		self.textmanager = TextManager(self, prefs)
 		self.textmanager.set_style_talk()
 		self.textmanager.set_cursor_visible(gtk.FALSE)
 		self.textmanager.set_editable(gtk.FALSE)
@@ -241,7 +250,7 @@ class LogWindow:
 # === Create Notebook === #
 		label = unicode(_('Current'), 'utf-8')
 		self.logbook = LogBook(label)
-		self.logbook.set_tab_pos(int(self.app.prefs.get('logtabpos')))
+		self.logbook.set_tab_pos(self.logtabpos)
 		self.logbook.connect('switch-page', self.tab_changed)
 
 		self.create_tab(label)
@@ -291,15 +300,6 @@ class LogWindow:
 	def clear_message(self):
 		self.messagebar.set_text('')
 
-	def color_changed(self, script, sakura, kero, sync, error, URL):
-		self.textmanager.color_changed(script, sakura, kero, sync, error, URL)
-		list = self.logbook.get_active_loglist()
-		if not list or not list.is_selected():
-			return
-		self.select(list)
-	def font_changed(self, genfont, scfont):
-		self.textmanager.font_changed(genfont, scfont)
-
 	def autologging(self, path, compress=False):
 		list = self.logbook.get_current_loglist()
 		if not list:
@@ -362,8 +362,8 @@ class LogWindow:
 		if res == gtk.RESPONSE_OK:
 			if os.path.exists(filename):
 				logger = XMLLogOpener(self, filename,
-									  self.app.prefs.get('logtabfocus'),
-									  self.app.prefs.get('logpagepos'))
+									  self.logtabfocus,
+									  self.logpagepos)
 				logger.start()
 
 	def fetch(self, widget=None, data=None):
@@ -377,8 +377,8 @@ class LogWindow:
 			return
 
 		fetcher = LogFetchOperator(self, d.request, d.request_name,
-								   self.app.prefs.get('logtabfocus'),
-								   self.app.prefs.get('logpagepos'))
+								   self.logtabfocus,
+								   self.logpagepos)
 		fetcher.start()
 
 	def popup_from_logtab(self, widget, event, sender):
@@ -412,19 +412,36 @@ class LogWindow:
 		self.app.dispose_selection()
 		self.app.copy_clipboard(self.logbook.edit_copy(widget, data, target))
 
+	def modify_tab_title(self, widget, child):
+		title_label = self.logbook.get_tab_label(child).get_children()[0].get_children()[0]
+		title = title_label.get_text()
+		title = open_simple_entry_dialog(unicode(_('Please input title'), 'utf-8'),
+										 unicode(_('Please input title'), 'utf-8'),
+										 default=title,
+										 parent=self.window)
+		if title:
+			title_label.set_text(title)
+
 	def connect_for_logtab(self, list, child, eventbox):
+		logtab_popup_menu = gtk.Menu()
+		logtab_popup_menu.show()
+
 		save_menuitem = gtk.MenuItem(self.msg["save"])
 		save_menuitem.show()
 		save_menuitem.connect("activate", self.save_as_xml, list)
+
 		close_menuitem = gtk.MenuItem(self.msg["close"])
 		close_menuitem.show()
+
 		if self.logbook.current_is(list):
 			close_menuitem.connect("activate", self.close_current_tab, child)
 		else:
 			close_menuitem.connect("activate", self.close_tab, child)
+			modify_menuitem = gtk.MenuItem(self.msg["modify tab title"])
+			modify_menuitem.show()
+			modify_menuitem.connect("activate", self.modify_tab_title, child)
+			logtab_popup_menu.append(modify_menuitem)
 
-		logtab_popup_menu = gtk.Menu()
-		logtab_popup_menu.show()
 		logtab_popup_menu.append(save_menuitem)
 		logtab_popup_menu.append(close_menuitem)
 		eventbox.connect("button-press-event", self.popup_from_logtab, logtab_popup_menu)
@@ -460,8 +477,8 @@ class LogWindow:
 	def update(self, mid, channel, ghost, script, receive_time):
 		datetime = time.strftime("%y/%m/%d %H:%M:%S", receive_time)
 		close_button, eventbox, child = self.logbook.update(mid, channel, ghost, script, datetime,
-															pos=self.app.prefs.get('logpagepos'),
-															focus=self.app.prefs.get('logtabfocus'))
+															pos=self.logpagepos,
+															focus=self.logtabfocus)
 
 		if child and close_button and eventbox:
 			# if Tab named `Current' Created
@@ -526,10 +543,6 @@ class LogWindow:
 			self.select(list)
 			self.update_rows(list)
 
-	def tab_pos_changed(self, pos):
-		if self.logbook.get_tab_pos() != pos:
-			self.logbook.set_tab_pos(pos)
-
 	def search(self, widget=None, data=None):
 		self.logbook.search(self.s_arrow.get_property('arrow-type'),
 							self.search_entry.get_text(),
@@ -612,6 +625,7 @@ class LogWindow:
 		mid, type = self.logbook.voting(widget, data, self.window)
 		if mid is None or type is None:
 			return
+
 		self.app.vote_message(mid, type)
 
 	def agreeing(self, widget, data):
@@ -697,6 +711,46 @@ class LogWindow:
 		else:
 			self.msgframe.show()
 
+	### notify preference changed start
+	def tab_pos_changed(self, pos):
+		if self.logbook.get_tab_pos() != pos:
+			self.logbook.set_tab_pos(pos)
+			self.logtabpos = pos
+
+	def color_changed(self, script, sakura, kero, sync, error, URL):
+		self.textmanager.color_changed(script, sakura, kero, sync, error, URL)
+		list = self.logbook.get_active_loglist()
+		if not list or not list.is_selected():
+			return
+		self.select(list)
+
+	def font_changed(self, genfont, scfont):
+		self.textmanager.font_changed(genfont, scfont)
+
+	def browser_changed(self, browser):
+		self.textmanager.browser_changed(browser)
+
+	def page_pos_changed(self, pos):
+		self.logpagepos = pos
+
+	def log_tab_focus_changed(self, focus):
+		self.logtabfocus = focus
+
+	def receive_preferences_changed(self, prefs):
+		self.tab_pos_changed(int(prefs[PreferenceManager.PREF_POSITION_TAB]))
+		self.page_pos_changed(prefs[PreferenceManager.PREF_POSITION_PAGE])
+		self.log_tab_focus_changed(prefs[PreferenceManager.PREF_FOCUS_TAB])
+		self.color_changed(prefs[PreferenceManager.PREF_COLOR_SCRIPT],
+						   prefs[PreferenceManager.PREF_COLOR_SAKURA],
+						   prefs[PreferenceManager.PREF_COLOR_KERO],
+						   prefs[PreferenceManager.PREF_COLOR_SYNCHRONIZED],
+						   prefs[PreferenceManager.PREF_COLOR_ERROR],
+						   prefs[PreferenceManager.PREF_COLOR_URL])
+		self.font_changed(prefs[PreferenceManager.PREF_FONT_GENERAL],
+						  prefs[PreferenceManager.PREF_FONT_SCRIPT])
+		self.browser_changed(prefs[PreferenceManager.PREF_BROWSER_COMMAND])
+	### notify preference changed end
+
 	def help(self, event=None):
 		pass
 
@@ -760,6 +814,7 @@ class LogWindow:
 			"save":  unicode(_("Save as XML"), "utf-8"),
 			"fetch":  unicode(_("Fetch logs"), "utf-8"),
 			"close":  unicode(_("Close"), "utf-8"),
+			"modify tab title":  unicode(_("Modify tab title"), "utf-8"),
 			"copy script":   unicode(_("Copy script"), "utf-8"),
 			"copy ghostname": unicode(_("Copy ghost name"), "utf-8"),
 			"copy channel":   unicode(_("Copy channel"), "utf-8"),
