@@ -12,7 +12,7 @@
 #  implied warranty of MERCHANTABILITY or FITNESS FOR A PARTICULAR
 #  PURPOSE.  See the GNU General Public License for more details.
 #
-# $Id: ghost.py,v 1.11 2004/09/10 16:07:41 atzm Exp $
+# $Id: ghost.py,v 1.12 2004/10/03 04:14:39 atzm Exp $
 #
 
 import gtk
@@ -74,56 +74,56 @@ class Ghost:
 					continue
 
 				elif line[:7] == 'sakura=':
-					self.sakura = self.expand_quote(unicode(line[7:], 'sjis', 'replace'))
+					self.sakura = expand_quote(unicode(line[7:], 'sjis', 'replace'))
 					self.debugprint('Sakura name', self.sakura)
 
 				elif line[:5] == 'unyu=':
-					self.unyu = self.expand_quote(unicode(line[5:], 'sjis', 'replace'))
+					self.unyu = expand_quote(unicode(line[5:], 'sjis', 'replace'))
 					self.debugprint('Unyu name', self.unyu)
 
 				elif line[:5] == 'user=':
-					self.user = self.expand_quote(unicode(line[5:], 'sjis', 'replace'))
+					self.user = expand_quote(unicode(line[5:], 'sjis', 'replace'))
 					self.debugprint('User name', self.user)
 
 				elif line[:9] == 'craftman=':
-					self.craftman = self.expand_quote(unicode(line[9:], 'sjis', 'replace'))
+					self.craftman = expand_quote(unicode(line[9:], 'sjis', 'replace'))
 					self.debugprint('Craftman', self.craftman)
 
 				elif line[:4] == 'url=':
-					self.url = self.expand_quote(unicode(line[4:], 'sjis', 'replace'))
+					self.url = expand_quote(unicode(line[4:], 'sjis', 'replace'))
 					self.debugprint('URL', self.url)
 
 				elif line[:7] == 'hpname=':
-					self.hpname = self.expand_quote(unicode(line[7:], 'sjis', 'replace'))
+					self.hpname = expand_quote(unicode(line[7:], 'sjis', 'replace'))
 					self.debugprint('HP name', self.hpname)
 
 				elif line[:7] == 'update=':
-					self.update = self.expand_quote(unicode(line[7:], 'sjis', 'replace'))
+					self.update = expand_quote(unicode(line[7:], 'sjis', 'replace'))
 					self.debugprint('update', self.update)
 
 				elif line[:8] == 'sakura2=':
-					self.sakura2 = self.expand_quote(unicode(line[8:], 'sjis', 'replace'))
+					self.sakura2 = expand_quote(unicode(line[8:], 'sjis', 'replace'))
 					self.debugprint('Sakura2 name', self.sakura2)
 
 				elif line[:10] == 'ghostname=':
-					self.ghostname = self.expand_quote(unicode(line[10:], 'sjis', 'replace'))
+					self.ghostname = expand_quote(unicode(line[10:], 'sjis', 'replace'))
 					self.debugprint('Ghost name', self.ghostname)
 
 				elif line[:10] == 'supported=':
-					self.supported = self.expand_quote(unicode(line[10:], 'sjis', 'replace'))
+					self.supported = expand_quote(unicode(line[10:], 'sjis', 'replace'))
 					self.debugprint('Supported', self.supported)
 
 				elif line[:14] == 'sakura-action=':
-					self.sakura_action = self.expand_quote(unicode(line[14:], 'sjis', 'replace'))
+					self.sakura_action = expand_quote(unicode(line[14:], 'sjis', 'replace'))
 					self.debugprint('Sakura Action', self.sakura_action)
 
 				elif line[:7] == 'inform=':
-					self.inform = self.expand_quote(unicode(line[7:], 'sjis', 'replace'))
+					self.inform = expand_quote(unicode(line[7:], 'sjis', 'replace'))
 					self.debugprint('Information', self.inform)
 
 				# get a svg_image_file
 				elif line[:12] == 'surfacefile=':
-					self.surfacefile = self.expand_quote(line[12:])
+					self.surfacefile = expand_quote(line[12:])
 					self.debugprint('Ghost img file', self.surfacefile)
 
 				# make a surface_id to splite_id dictionary
@@ -217,14 +217,6 @@ class Ghost:
 		if self.debug:
 			sys.stderr.write("%-15s: %s\n" % (desc, text.encode('euc-jp')))
 
-	EXPAND_QUOTE_REGEX = re.compile('"(.*)"')
-	def expand_quote(self, text):
-		try:
-			text = self.EXPAND_QUOTE_REGEX.match(text).group(1)
-		except AttributeError:
-			pass
-		return text	
-
 	def __str__(self):
 		if self.sakura:
 			return self.sakura
